@@ -13,8 +13,9 @@ from flask_bootstrap import Bootstrap
 from tuxpub.filters import datetimeformat, file_name, file_size, folder_name
 from tuxpub.resources import s3_server
 from tuxpub.config import TuxConfig
+from re import sub
 
-__version__ = "0.1.8"
+__version__ = "0.1.10"
 
 
 def create_app():
@@ -47,12 +48,23 @@ def create_app():
     @app.route("/", defaults={"dummy": ""})
     @app.route("/<path:dummy>")
     def fallback(dummy=""):
-        """ Process an arbitrary request. """
+        """Process an arbitrary request."""
         url = dummy
 
         # If the url is to a specific object, serve it.
-        if s3_handler.key_exists(url):
-            return redirect(s3_handler.create_signed_url(url), code=302)
+        (exists, head) = s3_handler.key_exists(url)
+        if exists:
+            if request.method == "HEAD":
+                resp = make_response("", 200)
+                md = head["ResponseMetadata"]["HTTPHeaders"]
+                resp.headers["Etag"] = md["etag"]
+                resp.headers["Content-Length"] = md["content-length"]
+                if "content-type" in md:
+                    resp.headers["Content-Type"] = md["content-type"]
+                resp.headers["Last-Modified"] = md["last-modified"]
+                return resp
+            else:
+                return redirect(s3_handler.create_signed_url(url), code=302)
 
         # Add a trailing slash to turn the url into a directory, unless we're
         # serving the index page (in which case url will be empty, and adding a
@@ -74,7 +86,7 @@ def create_app():
 
         # Retrieve the files and folders in the local path
         (files, folders, next_continuation_token) = s3_handler.get_files_and_folders(
-            url
+            sub("/+", "/", url)
         )
 
         # No files or folders found.
@@ -99,7 +111,7 @@ def create_app():
             )
 
     def export_files(export_format, files=[], folders=[], base_url=""):
-        """ Return the list of files in an alternate format (like json) """
+        """Return the list of files in an alternate format (like json)"""
 
         if export_format not in ["json"]:
             return "Export format not supported", 501
