@@ -54,13 +54,13 @@ class s3_server:
             head = self.client.head_object(Bucket=self.bucket, Key=key)
             if head.get("ContentLength") == 0:
                 # Disregard empty objects
-                return False
+                return (False, None)
         except (
             botocore.exceptions.ParamValidationError,
             botocore.exceptions.ClientError,
         ):
-            return False
-        return True
+            return (False, None)
+        return (True, head)
 
     def create_signed_url(self, key):
         return self.client.generate_presigned_url(
